djmongo - A Drop-in Django Application for MongoDB
==================================================

django-djmongo is an "API in a Box".  It provides a web-based UI for MongoDB,
the ability to import data, and create RESTful APIs without the need to 
write code. For beginners, it is easier to start with our sample project
with Djmongo already configured. https://github.com/videntity/djmsample.

You can also install this on top of https://github.com/TransparentHealth/sharemyhealth 


See the [Wiki](https://github.com/videntity/django-djmongo/wiki/Installation) page for installation and further documentation.
